magneticalc.Menu.Menu

# ``magneticalc`.`Menu`.`Menu``

class documentation

`class Menu:`

Constructor: `Menu(gui)`

View In Hierarchy

Menu class.

Method | `__init__` | Creates the menu bar.
Method | `reload` | Reloads the menu.
Method | `update` | Updates all menus.
Instance Variable | `file_menu` | Undocumented
Instance Variable | `gui` | Undocumented
Instance Variable | `help_menu` | Undocumented
Instance Variable | `options_menu` | Undocumented
Instance Variable | `view_menu` | Undocumented
Instance Variable | `wire_menu` | Undocumented

def __init__(self, gui: `GUI`):

Creates the menu bar.

Parameters
gui: `GUI` | GUI

def reload(self):

Reloads the menu.

def update(self):

Updates all menus.

file_menu =

Undocumented

gui =

Undocumented

help_menu =

Undocumented

options_menu =

Undocumented

view_menu =

Undocumented

wire_menu =

Undocumented